@@ -77,6 +77,7 @@ function replaceCurrentCell(tracker, code) {
   var maxSimilarity = 0;
   var maxIndex = -1;
   var lastEmptyCell = -1; 
+  var lastCellWithExclamationMark = -1;
   //remove lines with python comments from code
   const codeMinusComments = code.split("\n").filter(function(line) {
     return !line.startsWith("#");
@@ -86,7 +87,6 @@ function replaceCurrentCell(tracker, code) {
     const cell = currentNotebook.content.model.cells.get(i);
     const cellContent = cell.value.text;
     if (cellContent.includes(codeMinusComments)) {
-      console.log("Code already exists in cell, ignoring " + i);
       return; 
     }
     if (cellContent.trim().length == 0) {
@@ -97,17 +97,24 @@ function replaceCurrentCell(tracker, code) {
       maxSimilarity = similarityValue;
       maxIndex = i;
     }
+    if (cellContent.startsWith("!")) {
+      lastCellWithExclamationMark = i;
+    }
   }
   if (maxSimilarity > 0.8) {
     const cell = currentNotebook.content.model.cells.get(maxIndex);
     cell.value.text = code;
   } else {
-    const index = currentNotebook.content.activeCellIndex;
+    //find the index of the last cell that starts with ! and add the cell after it
     if (code.startsWith("!")) {
       //add cell at the beginning of the notebook
       const cell = currentNotebook.content.model.contentFactory.createCodeCell({});
       cell.value.text = code;
       currentNotebook.content.model.cells.insert(0, cell);
+    } else if (code.startsWith("%") && !code.startsWith("%%")) {
+        const cell = currentNotebook.content.model.contentFactory.createCodeCell({});
+        cell.value.text = code;
+        currentNotebook.content.model.cells.insert(lastCellWithExclamationMark + 1, cell);
     } else if (lastEmptyCell != -1) {
       const cell = currentNotebook.content.model.cells.get(lastEmptyCell);
       cell.value.text = code; 
@@ -251,7 +258,7 @@ const plugin = {
             return;
           }
           const currentCell = window.currentCellText();
-          const errorPrompt = "My code has an error. Ideally give me a quick command to fix it. If that's not available give me python code to fix it. Assume i dont have a credentials or key file. \n\nCode: \n\n" + currentCell.text + "\n\nError: \n\n" + currentCell.output;
+          const errorPrompt = "My code has an error. \n\nCode: \n\n" + currentCell.text + "\n\nError: \n\n" + currentCell.output;
           window.pastePrompt(errorPrompt); 
         }
       });
